import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import FormProgress from 'components/CommonKit/FormProgress/FormProgress'
import Content from 'components/Content/Content'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import useKonnectorAuth from 'components/Hooks/useKonnectorAuth'
import { useClient } from 'cozy-client'
import { FORM_DOCTYPE } from 'doctypes'
import { FluidType } from 'enums'
import { AccountEPGLData } from 'models'
import React, { useCallback, useEffect, useRef, useState } from 'react'
import { useNavigate } from 'react-router-dom'
import { useAppSelector } from 'store/hooks'
import '../connection.scss'
import { createInitialEpglState, useFormData } from '../useForm'
import StepConsent from './StepConsent'
import { StepIdentity } from './StepIdentity'

export enum EpglSteps {
  Identity,
  Consent,
}
/**
 * http://ecolyo.cozy.tools:8080/#/connect/water
 */
export const EpglConnectView = () => {
  const client = useClient()
  const navigate = useNavigate()
  const { formData } = useFormData()
  const { fluidStatus } = useAppSelector(state => state.ecolyo.global)
  const currentFluidStatus = fluidStatus[FluidType.WATER]
  const account = currentFluidStatus.connection.account

  const [launchConnection, setLaunchConnection] = useState(false)
  const [currentStep, setCurrentStep] = useState<EpglSteps>(EpglSteps.Identity)
  const [epglState, setEpglState] = useState<AccountEPGLData>(() =>
    createInitialEpglState()
  )
  const [formConsent, setFormConsent] = useState({
    dataConsent: false,
    contractConfirm: false,
  })

  const mainContentRef = useRef<HTMLDivElement>(null)
  const focusMainContent = () => {
    setTimeout(() => mainContentRef.current?.focus(), 0)
  }

  const [connect, update] = useKonnectorAuth(FluidType.WATER, {
    eglAuthData: epglState,
  })

  useEffect(() => {
    setEpglState(prevState => ({
      ...prevState,
      ...createInitialEpglState(formData),
    }))
  }, [formData])

  useEffect(() => {
    async function launchConnect() {
      if (launchConnection) {
        setLaunchConnection(false)
        if (!account) {
          await connect()
        } else {
          await update()
        }

        navigate('/consumption/water')
      }
    }
    launchConnect()
  }, [account, connect, launchConnection, navigate, update])

  const isNextValid = useCallback(() => {
    if (currentStep === EpglSteps.Identity) {
      return (
        epglState.contractId !== '' &&
        epglState.meteringId !== '' &&
        epglState.contractId.length === 7 &&
        epglState.meteringId.length === 11
      )
    } else if (currentStep === EpglSteps.Consent) {
      return formConsent.dataConsent && formConsent.contractConfirm
    }
    return false
  }, [
    currentStep,
    formConsent.dataConsent,
    formConsent.contractConfirm,
    epglState.contractId,
    epglState.meteringId,
  ])

  const handleNext = useCallback(() => {
    if (!isNextValid()) return
    if (currentStep < EpglSteps.Consent) {
      setCurrentStep(prev => prev + 1)
      client.save({
        ...formData,
        _type: FORM_DOCTYPE,
        contractId: epglState.contractId,
        meteringId: epglState.meteringId,
      })
    }
    if (currentStep === EpglSteps.Consent) {
      setLaunchConnection(true)
    }
    focusMainContent()
  }, [
    client,
    currentStep,
    epglState.contractId,
    epglState.meteringId,
    formData,
    isNextValid,
  ])

  const handlePrev = () => {
    setCurrentStep(prev => prev - 1)
    focusMainContent()
  }

  const renderStep = (step: EpglSteps) => {
    if (step === EpglSteps.Identity) {
      return <StepIdentity formData={epglState} setFormData={setEpglState} />
    }
    return (
      <StepConsent formConsent={formConsent} setFormConsent={setFormConsent} />
    )
  }

  return (
    <>
      <CozyBar titleKey="common.title_water_connect" displayBackArrow={true} />
      <Header
        desktopTitleKey="common.title_water_connect"
        displayBackArrow={true}
      />
      <Content>
        <div ref={mainContentRef} className="connectView" tabIndex={-1}>
          <div className="stepContainer">
            <FormProgress
              currentStep={currentStep}
              totalSteps={Object.keys(EpglSteps).length / 2}
            />
            {renderStep(currentStep)}
          </div>
          <FormNavigation
            handlePrevious={handlePrev}
            handleNext={handleNext}
            isLoading={false}
            disableNextButton={!isNextValid()}
            disablePrevButton={currentStep === EpglSteps.Identity}
            isLastStep={currentStep === EpglSteps.Consent}
          />
        </div>
      </Content>
    </>
  )
}
