import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React from 'react'

const EpglModalHint = ({
  open,
  handleCloseClick,
}: {
  open: boolean
  handleCloseClick: () => void
}) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('auth.eglgrandlyon.accessibility.modalHintsTitle')}
      </div>
      <StyledIconButton
        icon={CloseIcon}
        onClick={handleCloseClick}
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
      />
      <div className="hintModal">
        <h1 className="text-20-bold">
          {t('auth.eglgrandlyon.hintsModal.title')}
        </h1>
        <div className="content">
          <div>
            <p
              className="epglText"
              dangerouslySetInnerHTML={{
                __html: t('auth.eglgrandlyon.hintsModal.description'),
              }}
            />
            <ul className="text-16-normal">
              <li
                dangerouslySetInnerHTML={{
                  __html: t('auth.eglgrandlyon.hintsModal.contractId'),
                }}
              />
              <li
                dangerouslySetInnerHTML={{
                  __html: t('auth.eglgrandlyon.hintsModal.meteringId'),
                }}
              />
            </ul>
          </div>
          <Button onClick={handleCloseClick} className="btnPrimary">
            {t('auth.eglgrandlyon.hintsModal.okButton')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EpglModalHint
