import { act, render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import { TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import { Provider } from 'react-redux'
import * as chartActions from 'store/chart/chart.slice'
import { createMockEcolyoStore, mockChartState } from 'tests/__mocks__/store'
import { TodayButton } from './TodayButton'

const setCurrentTimeStepSpy = jest.spyOn(chartActions, 'setCurrentTimeStep')
const setCurrentIndexSpy = jest.spyOn(chartActions, 'setCurrentIndex')
const setSelectedDateSpy = jest.spyOn(chartActions, 'setSelectedDate')

describe('TodayButton component', () => {
  it('should go to todays day with timestep week', async () => {
    const store = createMockEcolyoStore({
      chart: {
        ...mockChartState,
        currentTimeStep: TimeStep.YEAR,
        selectedDate: DateTime.local().setZone('utc', {
          keepLocalTime: true,
        }),
      },
    })
    render(
      <Provider store={store}>
        <TodayButton />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('timestep.today'))
    })
    expect(setCurrentTimeStepSpy).toHaveBeenCalledTimes(1)
    expect(setCurrentTimeStepSpy).toHaveBeenCalledWith(TimeStep.WEEK)
    expect(setCurrentIndexSpy).toHaveBeenCalledTimes(1)
    expect(setSelectedDateSpy).toHaveBeenCalledTimes(1)
  })
})
