import { render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import { TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import DateNavigator from './DateNavigator'

const mockedDate = DateTime.local(2021, 7, 1)
  .setZone('utc', {
    keepLocalTime: true,
  })
  .startOf('day')

describe('DateNavigator component', () => {
  it('should be rendered correctly', () => {
    const { container } = render(
      <DateNavigator
        disableNext={false}
        disablePrev={false}
        handleNextDate={jest.fn()}
        handlePrevDate={jest.fn()}
        navigatorDate={mockedDate}
        timeStep={TimeStep.MONTH}
      />
    )
    expect(container).toMatchSnapshot()
  })

  it('should test navigation functions', async () => {
    const mockHandleNextDate = jest.fn()
    const mockHandlePrevDate = jest.fn()
    render(
      <DateNavigator
        disableNext={false}
        disablePrev={false}
        handleNextDate={mockHandleNextDate}
        handlePrevDate={mockHandlePrevDate}
        navigatorDate={mockedDate}
        timeStep={TimeStep.MONTH}
      />
    )
    await userEvent.click(
      screen.getByLabelText('consumption.accessibility.button_previous_value')
    )
    expect(mockHandlePrevDate).toHaveBeenCalledTimes(1)
    await userEvent.click(
      screen.getByLabelText('consumption.accessibility.button_next_value')
    )
    expect(mockHandleNextDate).toHaveBeenCalledTimes(1)
  })

  it('should not be able to click nav buttons', () => {
    render(
      <DateNavigator
        disableNext={true}
        disablePrev={true}
        handleNextDate={jest.fn()}
        handlePrevDate={jest.fn()}
        navigatorDate={mockedDate}
        timeStep={TimeStep.MONTH}
      />
    )
    const prev = screen.queryByLabelText(
      'consumption.accessibility.button_previous_value'
    )
    const next = screen.queryByLabelText(
      'consumption.accessibility.button_next_value'
    )
    expect(prev).toBeDisabled()
    expect(next).toBeDisabled()
  })
})
