import { MenuItem, Select } from '@material-ui/core'
import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { ProfileTypeStepForm } from 'enums'
import { DateTime } from 'luxon'
import { ProfileType, ProfileTypeAnswer, ProfileTypeValues } from 'models'
import React, { useState } from 'react'
import { formatTwoDigits, getMonthFullName } from 'utils/utils'

interface ProfileTypeFormDateSelectionProps {
  step: ProfileTypeStepForm
  profileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType: ProfileType) => void
  setPreviousStep: () => void
}

interface SelectionMonth {
  label: string
  value: string
}

const ProfileTypeFormDateSelection = ({
  step,
  profileType,
  answerType,
  setNextStep,
  setPreviousStep,
}: ProfileTypeFormDateSelectionProps) => {
  const { t } = useI18n()
  const [selectedYear, setSelectedYear] = useState<number>(DateTime.now().year)
  const [selectedMonth, setSelectedMonth] = useState<SelectionMonth>(() => ({
    label: DateTime.now().toLocaleString({ month: 'long' }),
    value: formatTwoDigits(DateTime.now().month), // Date.getMonth starts at 0
  }))
  const buildISODate = (year: string, month: string) =>
    DateTime.fromISO(`${year}-${month}-01`)

  const [answer, setAnswer] = useState<ProfileTypeValues>(() =>
    buildISODate(selectedYear.toString(), selectedMonth.value)
  )

  const selectMonths: SelectionMonth[] = [
    {
      label: 'Janvier',
      value: '01',
    },
    {
      label: 'Février',
      value: '02',
    },
    {
      label: 'Mars',
      value: '03',
    },
    {
      label: 'Avril',
      value: '04',
    },
    {
      label: 'Mai',
      value: '05',
    },
    {
      label: 'Juin',
      value: '06',
    },
    {
      label: 'Juillet',
      value: '07',
    },
    {
      label: 'Août',
      value: '08',
    },
    {
      label: 'Septembre',
      value: '09',
    },
    {
      label: 'Octobre',
      value: '10',
    },
    {
      label: 'Novembre',
      value: '11',
    },
    {
      label: 'Décembre',
      value: '12',
    },
  ]

  const selectYears = []
  const curYear = DateTime.now().year
  const limitYears = curYear - 10

  for (let i = curYear; i >= limitYears; i--) {
    selectYears.push(i)
  }

  const handleNext = () => {
    setNextStep({ ...profileType, [answerType.attribute]: answer })
  }

  function handleSelectMonth(value: string) {
    setSelectedMonth({
      value: value,
      label: getMonthFullName(parseInt(value)),
    })
    setAnswer(buildISODate(selectedYear.toString(), value))
  }

  function handleSelectYear(value: string) {
    setSelectedYear(parseInt(value))
    setAnswer(buildISODate(value, selectedMonth.value))
  }

  /** If current year, only show past and present months else show full months */
  const renderMonths =
    selectedYear === DateTime.now().year
      ? selectMonths.slice(0, DateTime.now().month)
      : selectMonths

  return (
    <>
      <div className="profile-form-container">
        <div className="profile-question-label">
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answer !== null && (
          <div className="select-container">
            <div className="date-select">
              <Select
                labelId="selectMonthDate"
                className="month"
                defaultValue={selectedMonth.value}
                value={selectedMonth.value}
                onChange={e => handleSelectMonth(e.target.value as string)}
              >
                {renderMonths.map(month => (
                  <MenuItem value={month.value} key={month.value}>
                    {month.label}
                  </MenuItem>
                ))}
              </Select>
            </div>
            <div className="date-select">
              <Select
                labelId="selectYearDate"
                className="year"
                defaultValue={selectedYear}
                value={selectedYear}
                onChange={e => handleSelectYear(e.target.value as string)}
              >
                {selectYears.map(year => (
                  <MenuItem value={year} key={year}>
                    {year}
                  </MenuItem>
                ))}
              </Select>
            </div>
          </div>
        )}
      </div>
      <FormNavigation
        handlePrevious={setPreviousStep}
        handleNext={handleNext}
        disableNextButton={answer === ''}
        isLastStep={true}
      />
    </>
  )
}

export default ProfileTypeFormDateSelection
